Changelog
=========


0.0.2 (2021-10-06)
------------------
- Including deps. [pappacena]
- Release: version 0.0.1 🚀 [pappacena]
- Release: version 0.0.1 🚀 [pappacena]


0.0.1 (2021-10-06)
------------------
- Adding some docs. [pappacena]
- Adding basic operations. [pappacena]
- Adding initial implementation. [pappacena]
- ✅ Ready to clone and code. [pappacena]
- Initial commit. [Thiago F Pappacena]


